"""Django Template Integrator - Automate frontend template integration into Django projects."""

__version__ = "1.0.0"
__author__ = "Django Template Integrator Team"
__description__ = "A CLI tool to automate Django template integration from frontend ZIP files"
